@@ -16,11 +16,11 @@
 module Graphics.HGL.Internals.Utilities(
 	bracket, bracket_,
 	safeTry,
-	E.Exception,
+	Exception,
         modMVar, modMVar_
 	) where
 
-import qualified Control.Exception as E (bracket, try, Exception)
+import qualified Control.Exception as E (bracket, try, IOException, tryJust, ioErrors)
 import Control.Concurrent( MVar, takeMVar, putMVar )
 
 bracket :: IO a -> (a -> IO b) -> (a -> IO c) -> IO c
@@ -30,8 +30,17 @@ bracket = E.bracket
 bracket_ :: IO a -> (a -> IO b) -> IO c -> IO c
 bracket_ left right m = bracket left right (const m)
 
-safeTry :: IO a -> IO (Either E.Exception a)
+type Exception = E.IOException
+safeTry :: IO a -> IO (Either Exception a)
+
+#if __GLASGOW_HASKELL >= 610 
+-- ghc-6.10
 safeTry = E.try
+#else
+-- ghc 6.8 (and below?)
+safeTry = E.tryJust E.ioErrors
+#endif
+
 
 ----------------------------------------------------------------
 -- Utilities
